@@ -6,11 +6,11 @@ from baidupcs_py.common.path import exists
 
 
 def decrypt_file(
-    from_encrypted: PathLike, to_decrypted: PathLike, encrypt_key: bytes = b""
+    from_encrypted: PathLike, to_decrypted: PathLike, encrypt_password: bytes = b""
 ):
     assert exists(from_encrypted)
 
-    dio = to_decryptio(open(from_encrypted, "rb"), encrypt_key=encrypt_key)
+    dio = to_decryptio(open(from_encrypted, "rb"), encrypt_password=encrypt_password)
 
     dpath = Path(to_decrypted)
     dir_ = dpath.parent
